Re-exports
pub use self::de::Deserialize;pub use self::ser::Serialize;pub use self::stream::Streamed;
Modules
- adapters
- Adapters to customize how values are serialized and deserialized.
- de
- Generic data structure deserialization framework.
- derive
derive - Support for automatic serializer and deserializer deriving.
- ext
- Extensions to the data model.
- hints
- Well-known formatting hints.
- io
io - Reading and writing values from and to streams.
- ser
- Generic data structure serialization framework.
- stream
- Reading and writing streams of values without doing IO.
Structs
- Bytes
- Bytes in the data model.
- Bytes
Format - How bytes are represented in formats without native bytes.
- Container
Shape - Facts about a map or sequence.
- Context
- Configuration for serializations and deserializations.
- Error
- An error for deser.
- Event
Data - Data attached to an event, detached from the event.
- Implicit
- A value whose type the format inferred from its text.
- Open
Enums open-enums - The registry of the variants of open enums.
- Position
- A position in the input.
- Source
- The source the input ranges refer to.
- State
- Gives access to the state of an ongoing serialization or deserialization.
- Text
- Text of an
Atom, borrowed or owned. - Track
Locations - Asks the formats to provide the
Source(a value of theContext).
Enums
- Atom
- An atom is a primitive value for serialization and deserialization.
- Error
Category - Describes the category of an error, see
Error::category. - Error
Kind - Describes the kind of error.
- Event
- An event represents an atomic serialization and deserialization event.
- Implicit
Value - The value of an
Implicitatom. - Order
- How significant the order of the elements of a container is.
Traits
- Error
Attachment - Additional information attached to an
Error. - Error
Context - Adds context to errors, see
State::add_error_context. - Open
Enum open-enums - A trait whose trait objects are open enums.
- Open
Variant open-enums - A type that is a variant of the open enum
O(a trait object).