As

Struct As 

pub struct As<T, A> { /* private fields */ }
Holds a value that serializes and deserializes with an adapter.

This implements Serialize and Deserialize with the adapter A. It’s useful to use adapters in places where #[deser(as = ...)] is not available. The wrapper dereferences to the value.

use deser::adapters::{As, DisplayFromStr};

let values: Vec<As<u32, DisplayFromStr>> = vec![As::new(1), As::new(2)];
assert_eq!(*values[0], 1);

Implementations

Source

impl<T, A> As<T, A>

pub fn new(value: T) -> As<T, A>

Wraps a value.

pub fn into_inner(self) -> T

Returns the wrapped value.