Flag

Struct Flag 

pub struct Flag;
A flag that is set if its key is given.

This is for bool fields that are switched on by giving their key, like ?recursive in a query string:

  • if the key is missing, the flag is false (no #[deser(default)] is needed)
  • an empty value (?recursive or ?recursive=) or null is true
  • other values are booleans, strings are parsed like lexical atoms (?recursive=0 is false)

The flag is serialized as boolean.

use deser::adapters::Flag;

#[derive(deser::Deserialize, deser::Serialize)]
pub struct Tree {
    #[deser(as = Flag, skip_serializing_if = std::ops::Not::not)]
    recursive: bool,
}