FromInto

Struct FromInto 

pub struct FromInto<U>(/* private fields */);
Converts from and into another type.

The value is deserialized as U and converted with Into and it’s serialized by cloning it and converting it into U. The value is optional if the converted value is, which means that with #[deser(skip_serializing_optionals)] the value is cloned and converted once more to find out.

use deser::{Deserialize, Serialize};
use deser::adapters::FromInto;

#[derive(Clone)]
pub struct Rgb(u8, u8, u8);

impl From<(u8, u8, u8)> for Rgb {
    fn from(value: (u8, u8, u8)) -> Rgb {
        Rgb(value.0, value.1, value.2)
    }
}

impl From<Rgb> for (u8, u8, u8) {
    fn from(value: Rgb) -> (u8, u8, u8) {
        (value.0, value.1, value.2)
    }
}

#[derive(Serialize, Deserialize)]
pub struct Theme {
    #[deser(as = FromInto<(u8, u8, u8)>)]
    background: Rgb,
}