MapSkipError

Struct MapSkipError 

pub struct MapSkipError<KA = Same, VA = Same>(/* private fields */);
Skips entries of a map which cannot be deserialized.

Keys are deserialized with the adapter KA and values with VA (both Same by default). If either of them fails, the rest of the entry is skipped (see Sink::recover). Only errors of the entries are handled, errors of the data format and of layers still fail the deserialization. Supported are BTreeMap and HashMap. Serialization uses the inner adapters.

use std::collections::BTreeMap;
use deser::Deserialize;
use deser::adapters::MapSkipError;

#[derive(Deserialize, PartialEq, Eq, PartialOrd, Ord)]
pub enum Kind {
    A,
    B,
}

#[derive(Deserialize)]
pub struct Weights {
    // entries with unknown kinds are skipped
    #[deser(as = MapSkipError)]
    weights: BTreeMap<Kind, f64>,
}