TryFromInto

Struct TryFromInto 

pub struct TryFromInto<U>(/* private fields */);
Converts from and into another type with fallible conversions.

This is like FromInto but uses TryFrom and TryInto. Failed conversions are reported as errors. Like with FromInto the value is cloned and converted once more with #[deser(skip_serializing_optionals)] to find out if it’s optional.

use deser::{Deserialize, Serialize};
use deser::adapters::TryFromInto;

#[derive(Clone)]
pub struct Percent(u8);

impl TryFrom<u64> for Percent {
    type Error = &'static str;
    fn try_from(value: u64) -> Result<Percent, Self::Error> {
        if value <= 100 {
            Ok(Percent(value as u8))
        } else {
            Err("out of range")
        }
    }
}

impl TryFrom<Percent> for u64 {
    type Error = std::convert::Infallible;
    fn try_from(value: Percent) -> Result<u64, Self::Error> {
        Ok(value.0 as u64)
    }
}

#[derive(Serialize, Deserialize)]
pub struct Progress {
    #[deser(as = TryFromInto<u64>)]
    done: Percent,
}