VecSkipError

Struct VecSkipError 

pub struct VecSkipError<A = Same>(/* private fields */);
Skips elements of a vector which cannot be deserialized.

The elements are deserialized with the adapter A (by default Same). If an element fails, the rest of it is skipped (see Sink::recover). Only errors of the elements are handled, errors of the data format and of layers still fail the deserialization. Serialization uses the inner adapter for the elements.

use deser::Deserialize;
use deser::adapters::VecSkipError;

#[derive(Deserialize)]
pub enum Kind {
    A,
    B,
}

#[derive(Deserialize)]
pub struct Item {
    // unknown kinds are skipped
    #[deser(as = VecSkipError)]
    kinds: Vec<Kind>,
}