pub enum Frame {
Value {
start: usize,
end: usize,
consumed: usize,
},
Incomplete {
consumed: usize,
},
End,
}Expand description
The result of StreamDeserializer::frame.
Variants
Value
The next value is complete.
Its bytes are input[start..end]. Afterwards the first consumed
bytes of the input (at least up to end) are discarded, the bytes
before start are skipped.
Incomplete
The input does not contain a complete value.
The first consumed bytes of the input are discarded, for instance
whitespace before the next value. If bytes were consumed, the
deserializer is invoked again right away (as a value might follow
them), otherwise once more input was read. At the end of the input
the deserializer must not return this without consuming bytes.
End
There are no more values.
This must only be returned at the end of the input.