Progress

Enum Progress 

pub enum Progress {
    Done {
        consumed: usize,
    },
    NeedMore {
        consumed: usize,
    },
    End,
}
Variants



Done

The value is complete, it used the first consumed bytes of the input.

Fields

consumed: usize


NeedMore

The value needs more input. The first consumed bytes of the input were used and are discarded, the next call continues with the input after them (followed by the new data).

Fields

consumed: usize


End

There are no more values.

This must only be returned at the end of the input.