CollectErrors

Struct CollectErrors 

pub struct CollectErrors { /* private fields */ }
Collects the errors of a whole deserialization (a value of the Context).

With this in the context, maps and sequences collect the errors of their items and deserialization continues to find the other errors (see State::set_collect_errors). The limit of errors is optional:

use deser::de::CollectErrors;
use deser::Context;

let config = deser_json::DeserializerConfig::builder()
    .context(Context::with(CollectErrors::with_max_errors(10)))
    .build();
let err = config.from_str::<Vec<u32>>(r#"["a", 1, true]"#).unwrap_err();
assert_eq!(err.errors().count(), 2);

Implementations

Source

impl CollectErrors

pub const fn new() -> CollectErrors

Collects errors without limit.

pub const fn with_max_errors(max: usize) -> CollectErrors

Collects errors up to a limit (see set_max_errors).

pub const fn set_max_errors(&mut self, max: usize)

Limits the number of errors that are collected (see State::set_max_errors).

pub const fn max_errors(&self) -> Option<usize>

Returns the limit of errors (see set_max_errors).