LayerEvent

Struct LayerEvent 

pub struct LayerEvent<'e, 'de>(/* private fields */);
An event that passes through the Layers.

Events emitted with emit_borrowed borrow from the data that is deserialized for 'de, other events are only valid for 'e. Layers that pass on the event they received retain this.

Implementations

Source

impl<'e, 'de> LayerEvent<'e, 'de>

pub fn new(event: Event<'e>) -> LayerEvent<'e, 'de>

Creates an event that is only valid for 'e.

pub fn borrowed(event: Event<'de>) -> LayerEvent<'e, 'de>

Creates an event that borrows from the data being deserialized.

pub fn event(&self) -> &Event<'_>

Returns the event.

pub fn is_borrowed(&self) -> bool

Returns true if the event borrows from the data being deserialized.