ErrorCategory

Enum ErrorCategory 

#[non_exhaustive]
pub enum ErrorCategory { Syntax, Eof, Data, Limit, Unsupported, Usage, Io, }
Describes the category of an error, see Error::category.

The categories tell apart whether the input was not well-formed or did not fit the values it was deserialized into. For instance an HTTP server would answer requests that fail with errors of the Syntax and Eof categories with 400 Bad Request and the ones of the Data category with 422 Unprocessable Entity.

More categories may be added in the future.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Syntax

The input is not well-formed (ErrorKind::Syntax).



Eof

The input ended early (ErrorKind::EndOfFile).



Data

The input is well-formed but does not fit the values, or a value cannot be serialized.



Limit

A limit was exceeded (ErrorKind::LimitExceeded).



Unsupported

A type or value cannot be represented (ErrorKind::UnsupportedType).



Usage

An API was used in a way that is not supported (ErrorKind::InvalidState) or deser is set up wrongly (ErrorKind::Configuration).



Io

Reading or writing failed (ErrorKind::Io).