Event

Enum Event 

pub enum Event<'a> {
    Atom(Atom<'a>),
    MapStart(ContainerShape),
    MapEnd,
    SeqStart(ContainerShape),
    SeqEnd,
}
An event represents an atomic serialization and deserialization event.

Serialization

Event and Emit are two close relatives. An Emit can be stateful whereas Event represents a single event. Atoms directly create an event whereas the emitters of compound values keep handing out values which again produce events. To go from Emits to events use the SerializeDriver method.

Deserialization

During deserialization events are passed to a DeserializeDriver to drive the deserialization.

The start events of maps and sequences carry the ContainerShape.

Variants



Atom(Atom<'a>)



MapStart(ContainerShape)



MapEnd



SeqStart(ContainerShape)



SeqEnd

Implementations

Source

impl<'a> Event<'a>

pub const fn map_start() -> Event<'static>

Creates the start event of a map with the default shape.

pub const fn seq_start() -> Event<'static>

Creates the start event of a sequence with the default shape.

pub fn as_borrowed(&self) -> Event<'_>

Returns an event borrowing from this one.

pub fn to_static(&self) -> Event<'static>

Makes a static clone of the event decoupling the lifetimes.