ExtValue

Struct ExtValue 

pub struct ExtValue<'a>(/* private fields */);
An extension value carried by Atom::Ext.

The value is either borrowed (which is typical during serialization and for values that formats create while parsing) or owned. Owned values are reference counted, so cloning an extension value is cheap.

Extension values are covariant in their lifetime and they can borrow data (see BorrowedExtension).

Implementations

Source

impl<'a> ExtValue<'a>

pub fn borrowed<T: Extension>(value: &'a T) -> ExtValue<'a>

Creates an extension value borrowing from a value.

pub fn owned<T: Extension>(value: T) -> ExtValue<'a>

Creates an extension value that owns the value.

pub fn borrowed_value<K: BorrowedExtension>( value: &'a K::Value<'a>, ) -> ExtValue<'a>

Creates an extension value borrowing from the value of an extension.

The extension is identified by its key K (see BorrowedExtension).

pub fn owned_value<K: BorrowedExtension>(value: K::Value<'a>) -> ExtValue<'a>

Creates an extension value that owns the value of an extension.

The extension is identified by its key K (see BorrowedExtension).

pub fn name(&self) -> &str

Returns the human readable name of the extension type.

pub fn fallback(&self) -> Atom<'_>

Returns the fallback atom of the value.

See Extension::fallback.

pub fn is<K: BorrowedExtension>(&self) -> bool

Returns true if the value is of the extension with the key K.

For extensions without lifetimes the key is the type.

pub fn downcast_ref<T: Extension>(&self) -> Option<&T>

Returns the value if it’s of type T.

use deser::ext::ExtValue;

let ext = ExtValue::owned(42u128);
assert_eq!(ext.downcast_ref::<u128>(), Some(&42));

For extensions that borrow use downcast_value_ref.

pub fn downcast_value_ref<K: BorrowedExtension>(&self) -> Option<&K::Value<'_>>

Returns the value if it’s of the extension with the key K.

See BorrowedExtension for an example. The returned value borrows from this extension value.

pub fn as_borrowed(&self) -> ExtValue<'_>

Returns a value borrowing from this one.

pub fn to_static(&self) -> ExtValue<'static>

Makes a static clone of the value decoupling the lifetimes.

Values that borrow data are detached from it (see BorrowedExtension::to_static).