Raw

Struct Raw 

pub struct Raw<'a, F: RawFormat> { /* private fields */ }
A value encoded in the format F.

A raw value holds a value in the encoding of a format, for instance JSON text with deser_json::RawJson. It can be deserialized later (with deserialize), stored or written out again unchanged:

  • If it’s deserialized from the format F, it holds the input of the value as it is. The format only validates the value and does not produce its events, which is fast. With the Borrowed adapter the input is borrowed.
  • Otherwise (from another format or where the format cannot pass on the input, see below) the value is encoded in the format F. The encoding can lose information that F cannot express (bytes in JSON for instance). To keep a value of any format without interpreting it, use Recording.

When serialized with the format F, the encoded value is written as it is. Other formats serialize the value it holds.

The input of values can only be passed on if the format knows before the value starts that a raw value is wanted. Derived structs (for their first 64 fields), maps, sequences, Option and Box ask for it. Values in other places (like the fields of flattened structs, the variants of enums and values that are buffered, for instance for untagged enums) are encoded.

Like Cow, raw values are deserialized owned, so a Raw<'static, F> can be deserialized from any data.

Implementations

Source

impl<'a, F: RawFormat> Raw<'a, F>

pub fn new<B: Into<Cow<'a, [u8]>>>(bytes: B) -> Result<Raw<'a, F>, Error>

Creates a raw value from its encoding.

The value is validated.

pub fn encode<T: Serialize + ?Sized>( value: &T, ) -> Result<Raw<'static, F>, Error>

Encodes a value.

pub fn as_bytes(&self) -> &[u8] ⓘ

Returns the encoded value.

pub fn is_borrowed(&self) -> bool

Returns true if the value borrows from the data it was deserialized from.

pub fn replay<'x>( &'x self, sink: SinkHandle<'_, 'x>, state: &mut State, ) -> Result<(), Error>

Replays the value into a sink.

The value is parsed, the sink can borrow its data.

pub fn deserialize<'x, T: Deserialize<'x>>(&'x self) -> Result<T, Error>

Deserializes the value.

The value can borrow from the raw value (and the data it borrows).

pub fn into_owned(self) -> Raw<'static, F>

Detaches the value from the data it borrows.

Source

impl<F: TextRawFormat> Raw<'_, F>

pub fn get(&self) -> &str

Returns the encoded value as text.