pub struct RawFormatId { /* private fields */ }Expand description
Identifies a RawFormat.
Formats are identified by the address of a static of this type. Unlike
the RawFormatInfo of the format it holds no functions: formats
declare which raw values they pass on with it (see
State::declare_raw_format), so a program
only contains the functions of the format (like its parser for
replay) if it uses its raw values.
Implementations
Sourceimpl RawFormatId
impl RawFormatId
Sourcepub const fn new(name: &'static str, is_text: bool) -> RawFormatId
pub const fn new(name: &'static str, is_text: bool) -> RawFormatId
Creates the identity of a format.
nameis the name of the format (like"json").is_textistrueif the encoding is text. The encoded values must then be valid UTF-8.