RawFormatInfo

Struct RawFormatInfo 

pub struct RawFormatInfo { /* private fields */ }
Describes a RawFormat at runtime.

Formats that can pass on the input of values define a static of this type. It travels with the input of values (see RawInput) so that code which does not know the format can still parse it. Formats are identified by their RawFormatId.

Implementations

Source

impl RawFormatInfo

pub const fn new( id: &'static RawFormatId, replay: for<'de> fn(&'de [u8], &mut DeserializeDriver<'_, 'de>) -> Result<(), Error>, encode: fn(SerializeRef<'_>) -> Result<Vec<u8>, Error>, fallback: for<'v> fn(&'v [u8]) -> Atom<'v>, ) -> RawFormatInfo

Creates the description of a format.

  • id identifies the format.
  • replay parses a value and emits its events into the driver.
  • encode encodes a value.
  • fallback returns the fallback atom of an encoded value (see Extension::fallback). It must be Atom::Null for null, so that optionals are None for it, and must not be an extension value.
pub const fn set_data(&mut self, data: &'static (dyn Any + Send + Sync))

Attaches data of the format to the description.

The format gets it back from the description of raw values that are requested (see data). Formats keep what only programs that use their raw values need here (like the scanner of raw values in the parser): as only raw values refer to the description, other programs do not contain it.

pub fn data(&self) -> Option<&'static (dyn Any + Send + Sync)>

Returns the data of the format (see set_data).

pub fn id(&self) -> &'static RawFormatId

Returns the identity of the format.

pub fn name(&self) -> &'static str

Returns the name of the format.

pub fn is_text(&self) -> bool

Returns true if the encoding of the format is text.