#[non_exhaustive]pub enum Layout {
Auto,
Compact,
Expanded,
}Expand description
How a map or sequence is laid out by formats that have a choice.
use deser::hints::Layout;
Layout::Compact.set(state);
assert_eq!(Layout::of(state), Layout::Compact);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
No preference, the format decides.
Compact
Keep the container compact, for instance on a single line (a flow collection in YAML, an inline table in TOML).
Expanded
Spread the container out, for instance one entry per line (a block collection in YAML, a section in TOML).
Implementations