Hinted

Struct Hinted 

pub struct Hinted<H, A = Same>(/* private fields */);
An adapter which sets a Hint and serializes the value with another adapter.

This is an adapter (see adapters) for all types that the adapter A supports, by default (Same) the value is serialized with its own Serialize implementation. It’s transparent when deserializing. Compact and Expanded are such adapters: Compact<Vec<Base64>> serializes a Vec<Vec<u8>> as base64 strings with Layout::Compact.