SerializeHandle

Enum SerializeHandle 

pub enum SerializeHandle<'a> {
    Borrowed(&'a dyn Serialize),
    Owned(Boxed<dyn Serialize + Send + 'a>),
}
A handle to a Serialize type.

During serialization it common to be in a situation where one needs to return locally constructed Serialize. This is where SerializeHandle comes in. In cases where the Serialize cannot be borrowed it can be boxed up inside the handle.

The equivalent for deserialization is the SinkHandle.

Variants



Borrowed(&'a dyn Serialize)

A borrowed reference to a Serialize.



Owned(Boxed<dyn Serialize + Send + 'a>)

A Serialize owned by the handle (see Boxed).

Owned values must be Send so that the serialization can move between threads.

Implementations

Source

impl<'a> SerializeHandle<'a>

pub fn to<S: Serialize + 'a>(val: &'a S) -> SerializeHandle<'a>

Create a borrowed handle to a Serialize.

pub fn arena<S: Serialize + Send + 'a>( val: S, state: &mut State, ) -> SerializeHandle<'a>

Creates an owned handle to a value in the arena of the serialization.

This is how owned values are typically created (for instance for Chunk::Forward), see Boxed.

pub fn heap<S: Serialize + Send + 'a>(val: S) -> SerializeHandle<'a>

Creates an owned handle to a value on the heap.

Unlike arena the value does not need a state and is independent of any serialization.