#[non_exhaustive]pub enum VariantRepr<'a> {
External,
Internal {
tag: &'a str,
},
Adjacent {
tag: &'a str,
content: &'a str,
},
Untagged,
}Expand description
How an enum variant is represented.
This corresponds to the representations of the derive (see
derive).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
External
Externally tagged: unit variants are their name, others a map with the name as key and the content as value.
Internal
Internally tagged: a map with the name in the given key and the fields of the content.
Adjacent
Adjacently tagged: a map with the name and the content in the given keys.
Untagged
Untagged: just the content.