pub enum Written {
Done,
Partial,
}Expand description
The result of StreamSerializer::drive_partial.
Variants
Done
The value is complete, the output holds the rest of it.
Partial
The value is not complete.
The output holds a part of it which the caller takes (and clears)
before it calls drive_partial
again with the same driver to continue.