Next

Struct Next 

pub struct Next<'n> { /* private fields */ }
Passes events on to the next Layer.

The last layer passes the events on to the format.

Implementations

Source

impl<'n> Next<'n>

pub fn value(&self) -> SerializeRef<'_>

Returns the value of the current event.

This is only useful to describe the value. If the driver does not pass on values (see EventSink::DESCRIBED), this is a value that describes nothing.

pub fn state(&self) -> &State

Returns the state.

pub fn state_mut(&mut self) -> &mut State

Returns the state mutably.

pub fn emit_key(&mut self, event: Event<'_>) -> Result<(), Error>

Passes an event on as map key.

This is like emit but the event is passed on with State::is_map_key set. This is useful for layers which hold back map keys and emit them later, when the state already describes the value.

pub fn emit(&mut self, event: Event<'_>) -> Result<(), Error>

Passes an event on.

This can be invoked any number of times per event.