pub enum Part<E, T> {
Element(E),
Done(T),
}Expand description
A part of a value that is read with the elements of its
Streamed sequence handed out.
Such a value is read in parts: first the elements, then the rest of the
value. This is the result of ElementReader::poll (and of
Reader::read_next of deser::io).
Variants
Element(E)
An element of the Streamed sequence of the value.
Done(T)
The value is complete (without the elements that were handed out).