BytesFormat

Struct BytesFormat 

pub struct BytesFormat(/* private fields */);
How bytes are represented in formats without native bytes.

It’s an extension value, usually configured in the Context (or in the State, see set). It’s used in three places:

  • The serializers of formats without native bytes (like JSON and TOML) write all bytes that do not request a format in it. The default is BytesFormat::BASE64.
  • Bytes can carry a format as fallback (see Bytes::fallback) which takes precedence over the format of the context. The BytesFallback adapter does this.
  • The types that expect bytes decode strings with it. Without a format lenient base64 is used. Strings are decoded as base64 for BytesFormat::SEQ.
use deser::adapters::Base64Url;
use deser::{BytesFormat, Context};

// writes and reads URL-safe base64 in formats without native bytes
let context = Context::with(BytesFormat::encoded::<Base64Url>());
use deser::adapters::Base64UrlNoPad;
use deser::BytesFormat;

const URL_SAFE: BytesFormat = BytesFormat::encoded::<Base64UrlNoPad>();
assert_eq!(URL_SAFE.encode(b"\xfb\xff").as_deref(), Some("-_8"));
// decoding is lenient
assert_eq!(URL_SAFE.decode("+/8=").unwrap(), b"\xfb\xff");
assert_eq!(BytesFormat::SEQ.encode(b"\x01\xff"), None);

Two formats are equal if they are both sequences or encodings with the same name.

Implementations

Source

impl BytesFormat

pub const BASE64: BytesFormat

Bytes are strings in base64 with the standard alphabet and padding.

This is the default.

pub const SEQ: BytesFormat

Bytes are sequences of integers.

This is how serde_json represents bytes.

pub const fn encoded<E: BytesEncoding>() -> BytesFormat

Bytes are strings in the given encoding.

pub fn of(state: &State) -> BytesFormat

Returns the format of a serialization or deserialization.

This is BytesFormat::BASE64 unless the state or the context has a different one.

pub fn set(self, state: &mut State)

Sets the format the types that expect bytes decode strings with.

pub fn name(&self) -> &'static str

Returns the name of the format.

This is the name of the encoding or seq.

pub fn encode(&self, bytes: &[u8]) -> Option<String>

Encodes bytes as string.

Returns None if bytes are sequences of integers.

pub fn decode(&self, s: &str) -> Result<Vec<u8>, Error>

Decodes bytes from a string.

For sequences of integers the string is decoded as base64.