TrackLocations

Struct TrackLocations 

pub struct TrackLocations(pub bool);
Asks the formats to provide the Source (a value of the Context).

Formats publish the byte range of every event, resolving them into lines and columns (for instance with the Spanned type of deser-location) also requires the source, which is a copy of the input. Formats only provide it if this is set to true in the context (or the state). The errors a deserialization fails with have their line and column either way, but for instance the keys collected with UnknownFields::Collect only have them with the source:

use deser::de::{Deserializer, IgnoredFields, UnknownFields};
use deser::{Context, Deserialize, TrackLocations};

#[derive(Deserialize)]
struct Config {
    name: String,
}

let config = deser_json::DeserializerConfig::builder()
    .context(Context::with(TrackLocations(true)))
    .build();
let input = "{\n  \"name\": \"demo\",\n  \"nmae\": \"x\"\n}";
let ignored = IgnoredFields::new();
deser_json::Deserializer::from_str_with_config(input, config)
    .deserialize_with::<Config, _>(|driver| {
        UnknownFields::Collect(ignored.clone()).set(driver.state_mut())
    })
    .unwrap();
let ignored = ignored.take();
assert_eq!((ignored[0].line(), ignored[0].column()), (Some(3), Some(3)));

Formats check this with of and set the Source before they emit the first event:

use deser::de::{DeserializeDriver, Deserializer};
use deser::{Error, Source, TrackLocations};

/// A format which provides the source if asked to.
struct Text<'a>(&'a str);

impl<'de> Deserializer<'de> for Text<'de> {
    fn drive(&mut self, driver: &mut DeserializeDriver<'_, 'de>) -> Result<(), Error> {
        if TrackLocations::of(driver.state()) {
            Source(self.0.into()).set(driver.state_mut());
        }
        driver.state_mut().set_input_range(0, self.0.len());
        driver.emit(self.0)
    }
}

Tuple Fields

0: bool

Implementations

Source

impl TrackLocations

pub fn of(state: &State) -> bool

Returns true if the formats provide the source.

pub fn set(self, state: &mut State)

Sets if the formats provide the source.