Crate deser_core

Crate deser_core 

The core of deser.

This crate is an implementation detail of deser, use the deser crate instead which re-exports everything in here together with the derive macros. The crates of the data formats depend on this crate so that they can be compiled without waiting for the derive macros.

Re-exports

pub use self::de::Deserialize;
pub use self::ser::Serialize;
pub use self::stream::Streamed;

Modules

adapters
Adapters to customize how values are serialized and deserialized.
de
Generic data structure deserialization framework.
derivederive
Support for automatic serializer and deserializer deriving.
ext
Extensions to the data model.
hints
Well-known formatting hints.
ioio
Reading and writing values from and to streams.
ser
Generic data structure serialization framework.
stream
Reading and writing streams of values without doing IO.

Macros

make_slot_wrapper
Creates a newtype wrapper around Option<T>.

Structs

Bytes
Bytes in the data model.
BytesFormat
How bytes are represented in formats without native bytes.
ContainerShape
Facts about a map or sequence.
Error
An error for deser.
EventData
Data attached to an event, detached from the event.
Implicit
A value whose type the format inferred from its text.
Position
A position in the input.
The source the input ranges refer to.
State
Gives access to the state of an ongoing serialization or deserialization.
Text
Text of an Atom, borrowed or owned.

Enums

Atom
An atom is a primitive value for serialization and deserialization.
ErrorKind
Describes the kind of error.
Event
An event represents an atomic serialization and deserialization event.
ImplicitValue
The value of an Implicit atom.
Order
How significant the order of the elements of a container is.

Traits

ErrorAttachment
Additional information attached to an Error.
ErrorContext
Adds context to errors, see State::add_error_context.