pub struct BytesFallback<F>(/* private fields */);Expand description
Represents bytes as bytes, with a fallback for formats without native bytes.
The bytes are serialized as bytes which carry the format F as
fallback (see Bytes::fallback). Formats with native bytes (like CBOR)
write them as bytes, formats without native bytes (like JSON and TOML)
write them in F: strings in an encoding or sequences
of integers for IntSeq. When deserializing native bytes and the
representation of F are accepted. It supports the types of
BytesBuf.
use deser::adapters::{Base64Url, BytesFallback, IntSeq};
use deser::{Deserialize, Serialize};
#[derive(Serialize, Deserialize)]
pub struct Blob {
// URL-safe base64 in JSON and TOML, bytes in CBOR
#[deser(as = BytesFallback<Base64Url>)]
sha1: [u8; 20],
#[deser(as = Option<BytesFallback<Base64Url>>)]
signature: Option<Vec<u8>>,
// `[1, 2]` in JSON and TOML, bytes in CBOR
#[deser(as = BytesFallback<IntSeq>)]
legacy: Vec<u8>,
}To use an encoding in all formats, use the encoding as adapter (for
instance #[deser(as = Base64Url)]). To change the representation of all
bytes, configure the format instead.