DefaultOnError

Struct DefaultOnError 

pub struct DefaultOnError<A = Same>(/* private fields */);
Uses the Default if a value cannot be deserialized.

The value is deserialized with the adapter A (by default Same). If that fails, the default value is used instead and the rest of the value is skipped (see Sink::recover). Only errors of the value are handled, errors of the data format and of layers (such as Limits) still fail the deserialization. Missing values are handled by the inner adapter. Serialization uses the inner adapter.

use deser::Deserialize;
use deser::adapters::DefaultOnError;

#[derive(Deserialize)]
pub enum Kind {
    A,
    B,
}

#[derive(Deserialize)]
pub struct Item {
    // unknown kinds become `None`
    #[deser(as = DefaultOnError)]
    kind: Option<Kind>,
}