pub struct Derived;Expand description
The adapter that uses the derived implementation of a type.
Adapters on a type (see container adapters)
replace its derived implementation. Adapters which wrap another
adapter can wrap the derived implementation with Derived, which is
written as _ in the attribute. This is how values are checked or converted after the
derived implementation deserialized them:
use deser::{Deserialize, State};
use deser::de::SinkHandle;
/// Deserializes with `A`, missing values are the default.
pub struct DefaultIfMissing<A>(std::marker::PhantomData<A>);
impl<'de, T: Default + Send, A: Deserialize<'de, T>> Deserialize<'de, T>
for DefaultIfMissing<A>
{
fn deserialize_into<'out>(
out: &'out mut Option<T>,
state: &mut State,
) -> SinkHandle<'out, 'de> {
A::deserialize_into(out, state)
}
fn initial_value() -> Option<T> {
Some(T::default())
}
}
#[derive(Deserialize, Default)]
#[deser(deserialize_as = DefaultIfMissing<_>)]
struct Limits {
max_connections: u32,
}
#[derive(Deserialize)]
struct Config {
limits: Limits,
}
// the limits are missing
let config: Config = deser_json::from_str("{}").unwrap();
assert_eq!(config.limits.max_connections, 0);The derived implementation is only available through this adapter for
the directions that have an adapter with _.