pub struct FromInto<U>(/* private fields */);Expand description
Converts from and into another type.
The value is deserialized as U and converted with Into and it’s
serialized by cloning it and converting it into U. The value is
optional if the converted value is, which means
that with #[deser(skip_serializing_optionals)] the value is cloned and
converted once more to find out.
use deser::{Deserialize, Serialize};
use deser::adapters::FromInto;
#[derive(Clone)]
pub struct Rgb(u8, u8, u8);
impl From<(u8, u8, u8)> for Rgb {
fn from(value: (u8, u8, u8)) -> Rgb {
Rgb(value.0, value.1, value.2)
}
}
impl From<Rgb> for (u8, u8, u8) {
fn from(value: Rgb) -> (u8, u8, u8) {
(value.0, value.1, value.2)
}
}
#[derive(Serialize, Deserialize)]
pub struct Theme {
#[deser(as = FromInto<(u8, u8, u8)>)]
background: Rgb,
}Trait Implementations
Sourceimpl<'de, T, U> Deserialize<'de, T> for FromInto<U>
impl<'de, T, U> Deserialize<'de, T> for FromInto<U>
Sourcefn deserialize_into<'out>(
out: &'out mut Option<T>,
state: &mut State,
) -> SinkHandle<'out, 'de>
fn deserialize_into<'out>( out: &'out mut Option<T>, state: &mut State, ) -> SinkHandle<'out, 'de>
Creates a sink that deserializes the value into the given slot. Read more
Sourcefn expecting() -> Cow<'static, str>
fn expecting() -> Cow<'static, str>
Returns what the value expects, for error messages. Read more
Sourcefn initial_value() -> Option<T>
fn initial_value() -> Option<T>
Provides the value of a missing struct field. Read more
Sourcefn deserialize_atom(
slot: &mut Slot<T, Self>,
atom: Atom<'_>,
state: &mut State,
) -> Result<(), Error>
fn deserialize_atom( slot: &mut Slot<T, Self>, atom: Atom<'_>, state: &mut State, ) -> Result<(), Error>
Deserializes an atom into the slot. Read more
Sourcefn deserialize_borrowed_atom(
slot: &mut Slot<T, Self>,
atom: Atom<'de>,
state: &mut State,
) -> Result<(), Error>
fn deserialize_borrowed_atom( slot: &mut Slot<T, Self>, atom: Atom<'de>, state: &mut State, ) -> Result<(), Error>
Deserializes an atom that borrows from the data being deserialized
into the slot. Read more
Sourcefn describe_type(d: &mut dyn Describe)
fn describe_type(d: &mut dyn Describe)
Describes the Rust shape of the type. Read more
Sourcefn deserialize_update<'out>(
value: &'out mut T,
state: &mut State,
) -> SinkHandle<'out, 'de>
fn deserialize_update<'out>( value: &'out mut T, state: &mut State, ) -> SinkHandle<'out, 'de>
Creates a sink that updates an existing value. Read more
Sourceimpl<T, U> Serialize<T> for FromInto<U>
impl<T, U> Serialize<T> for FromInto<U>
Sourcefn serialize<'a>(value: &'a T, state: &mut State) -> Result<Emit<'a>, Error>
fn serialize<'a>(value: &'a T, state: &mut State) -> Result<Emit<'a>, Error>
Serializes the value.
Sourcefn finish(value: &T, state: &mut State) -> Result<(), Error>
fn finish(value: &T, state: &mut State) -> Result<(), Error>
Invoked after the serialization finished. Read more
Sourcefn container_shape(value: &T) -> ContainerShape
fn container_shape(value: &T) -> ContainerShape
Returns the shape of the value if it’s a map or sequence. Read more