#[non_exhaustive]pub enum DuplicateKeys {
Last,
First,
Error,
}Expand description
What happens if a key is given more than once.
JSON objects can contain the same key more than once and query strings
commonly repeat keys. Where a single value is expected (the field of a
struct or an entry of a map) the policy decides what happens. It’s an
extension value in the State (see set). The default is
Error: if the same key could mean different values to
different parsers (a proxy might use the first value, the application the
last) the input is rejected.
use std::collections::BTreeMap;
use deser::de::{DeserializeDriver, DuplicateKeys};
use deser::Event;
let mut out = None::<BTreeMap<String, u32>>;
let mut driver = DeserializeDriver::new(&mut out);
DuplicateKeys::Error.set(driver.state_mut());
driver.emit(Event::map_start()).unwrap();
for value in [1u64, 2] {
driver.emit("a").unwrap();
driver.emit(value).unwrap();
}
let err = driver.emit(Event::MapEnd).unwrap_err();
assert_eq!(err.message(), "duplicate key in map");Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Last
The last value is used.
First
The first value is used, later ones are ignored.
Error
Duplicate keys are rejected.
Implementations
Sourceimpl DuplicateKeys
impl DuplicateKeys