pub struct LayerEvent<'e, 'de>(/* private fields */);Expand description
An event that passes through the Layers.
Events emitted with
emit_borrowed borrow
from the data that is deserialized for 'de, other events are only
valid for 'e. Layers that pass on the event they received retain
this.
Implementations
Sourceimpl<'e, 'de> LayerEvent<'e, 'de>
impl<'e, 'de> LayerEvent<'e, 'de>
Sourcepub fn new(event: Event<'e>) -> LayerEvent<'e, 'de>
pub fn new(event: Event<'e>) -> LayerEvent<'e, 'de>
Creates an event that is only valid for 'e.
Sourcepub fn borrowed(event: Event<'de>) -> LayerEvent<'e, 'de>
pub fn borrowed(event: Event<'de>) -> LayerEvent<'e, 'de>
Creates an event that borrows from the data being deserialized.
Sourcepub fn is_borrowed(&self) -> bool
pub fn is_borrowed(&self) -> bool
Returns true if the event borrows from the data being deserialized.