Next

Struct Next 

pub struct Next<'n, 'de> { /* private fields */ }
Passes events on to the next Layer.

The last layer passes the events on to the sinks.

Implementations

Source

impl<'n, 'de> Next<'n, 'de>

pub fn state(&self) -> &State

Returns the state.

pub fn state_mut(&mut self) -> &mut State

Returns the state mutably.

pub fn emit(&mut self, event: LayerEvent<'_, 'de>) -> Result<(), Error>

Passes an event on.

This can be invoked any number of times per event. Events that were passed on get the same input range (see State::input_range) and event data (see State::event), unless the layer changes them in the state.