pub struct Decimal(/* private fields */);Expand description
An exact decimal number of arbitrary precision.
This is a well-known extension type (see ext) which
holds the decimal as validated text in the syntax of JSON numbers
(-12.50, 1e-7). The text is kept as is, so trailing zeros (the
scale) are retained. The fallback is the text as string.
When deserializing, decimals, strings, integers and floats are accepted.
Number extension values (which text formats like JSON emit for
floats) are converted exactly.
use deser::ext::Decimal;
let value: Decimal = "-12.50".parse().unwrap();
assert_eq!(value.as_str(), "-12.50");
let (mantissa, exponent) = value.to_parts();
assert_eq!((mantissa.to_string(), exponent), ("-1250".to_string(), -2));
assert_eq!(Decimal::from_parts(&mantissa, exponent), value);With the rust_decimal and bigdecimal features the decimal types of
these crates serialize as Decimal.
Implementations
Sourceimpl Decimal
impl Decimal
Sourcepub fn new<S: Into<String>>(value: S) -> Result<Decimal, Error>
pub fn new<S: Into<String>>(value: S) -> Result<Decimal, Error>
Creates a decimal from its text representation.
The text has to follow the syntax of JSON numbers.
Sourcepub fn from_parts(mantissa: &BigInt, exponent: i64) -> Decimal
pub fn from_parts(mantissa: &BigInt, exponent: i64) -> Decimal
Creates a decimal from a mantissa and a base 10 exponent.
The value is mantissa * 10^exponent.
Sourcepub fn to_parts(&self) -> (BigInt, i64)
pub fn to_parts(&self) -> (BigInt, i64)
Returns the mantissa and the base 10 exponent.
The value is mantissa * 10^exponent. Exponents that do not fit
into i64 saturate.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Converts the decimal into its text.