pub struct Duration {
pub seconds: i64,
pub nanosecond: i32,
}Expand description
A signed, exact length of time.
This is a well-known extension type (see ext). The
seconds and nanoseconds always have the same sign: -1.5 seconds are
seconds: -1 and nanosecond: -500_000_000.
The fallback is the ISO 8601 representation as string (PT1H30M,
-PT0.5S). Only hours, minutes and seconds are used and accepted as
days, months and years are not of a fixed length. Fractions are only
supported for seconds.
use deser::ext::Duration;
let duration: Duration = "PT1H0.5S".parse().unwrap();
assert_eq!(duration, Duration { seconds: 3600, nanosecond: 500_000_000 });
assert_eq!(duration.to_string(), "PT1H0.5S");core::time::Duration serializes as Duration, as do the duration
types of jiff, chrono and time with the respective features.
Fields
seconds: i64The whole seconds.
nanosecond: i32The fraction of the second in nanoseconds (-999_999_999 to
999_999_999).
Implementations