RawInput

Struct RawInput 

pub struct RawInput<'a> { /* private fields */ }
The encoded input of a value.

This is a well-known borrowing extension (see ext) which carries the encoding of a value between formats and Raw values:

  • formats emit it for values that are requested as raw values (the values of Raw types). They validate the value and pass on its input instead of its events.
  • Raw values emit it when they are serialized and the serializer writes the format as it is (see State::declare_raw_format).

It knows its format, so it’s parsed into its value where it ends up in something that does not know it (for instance when a recording that holds it is serialized).

Implementations

Source

impl<'a> RawInput<'a>

pub unsafe fn new<B: Into<Cow<'a, [u8]>>>( bytes: B, format: &'static RawFormatInfo, ) -> RawInput<'a>

Creates the input of a value.

Safety

The input must be a single, valid value of the format. If the format is text, it must be valid UTF-8. Serializers of the format write the input as it is.

pub fn as_bytes(&self) -> &[u8] ⓘ

Returns the encoded value.

pub fn as_str(&self) -> Option<&str>

Returns the encoded value as text if the format is text.

pub fn format(&self) -> &'static RawFormatInfo

Returns the format of the value.

pub fn is<F: RawFormat>(&self) -> bool

Returns true if the value is of the format F.

pub fn is_format(&self, id: &'static RawFormatId) -> bool

Returns true if the value is of the format with the identity.

Serializers check with this whether they write a value as it is (unlike is, this does not refer to the functions of the format).

pub fn into_owned(self) -> RawInput<'static>

Detaches the input from the data it borrows.

pub fn record(&self) -> Result<RecordBuf<'_>, Error>

Records the value.

pub fn replay<'x>( &'x self, sink: SinkHandle<'_, 'x>, state: &mut State, ) -> Result<(), Error>

Replays the value into a sink.

The value is parsed, the sink can borrow its data.

pub fn deserialize<'x, T: Deserialize<'x>>(&'x self) -> Result<T, Error>

Deserializes the value.

The value can borrow from the input (and the data it borrows).