Timestamp

Struct Timestamp 

pub struct Timestamp {
    pub seconds: i64,
    pub nanosecond: u32,
}
An instant in time.

This is a well-known extension type (see ext) for points in time independent of a time zone, such as Unix timestamps. It holds the time since the Unix epoch (1970-01-01T00:00:00Z), ignoring leap seconds. The nanoseconds are always positive: -0.5 seconds are seconds: -1 and nanosecond: 500_000_000.

The fallback is the RFC 3339 representation in UTC as string. Instants outside of the years 0 to 9999 are written with an expanded year as in ISO 8601 (+10000-01-01T00:00:00Z).

use deser::ext::Timestamp;

let ts = Timestamp { seconds: 296638320, nanosecond: 0 };
assert_eq!(ts.to_string(), "1979-05-27T07:32:00Z");
assert_eq!("1979-05-27T00:32:00-07:00".parse::<Timestamp>().unwrap(), ts);

std::time::SystemTime serializes as Timestamp, as do the timestamp types of jiff, chrono and time with the respective features.

Fields

seconds: i64

The seconds since the Unix epoch.

nanosecond: u32

The fraction of the second in nanoseconds (0 to 999_999_999).

Implementations

Source

impl Timestamp

pub fn as_secs_f64(&self) -> f64

Returns the time since the epoch in seconds as float.

pub fn to_datetime(&self) -> Option<Datetime>

Converts the timestamp into an offset date-time in UTC.

Returns None if the year is outside of 0 to 9999.