pub trait Extension:
Any
+ Debug
+ Clone
+ PartialEq
+ Send
+ Sync {
// Required methods
fn name(&self) -> &str;
fn fallback(&self) -> Atom<'_>;
}Expand description
A type that can be passed through deser as an extension to the data model.
This is implemented for extension types without lifetimes, which covers
most extensions. Types that borrow data implement
BorrowedExtension instead.
See the module level documentation for more information.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".