pub unsafe trait TextRawFormat: RawFormat { }Expand description
A RawFormat whose encoding is text.
Raw values of such formats can be accessed as strings (see
Raw::get).
Safety
The format must be described as text (see RawFormatId::new): its
parser only passes on and its encoder only produces valid UTF-8.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".