pub struct Next<'n> { /* private fields */ }Expand description
Passes events on to the next Layer.
The last layer passes the events on to the format.
Implementations
Sourceimpl<'n> Next<'n>
impl<'n> Next<'n>
Sourcepub fn value(&self) -> SerializeRef<'_>
pub fn value(&self) -> SerializeRef<'_>
Returns the value of the current event.
This is only useful to describe the value.
If the driver does not pass on values (see
EventSink::DESCRIBED), this is
a value that describes nothing.